@@ -24,21 +24,10 @@ class HUBLogger:
         print(f"{PREFIX}Submitting checkpoint for " + self.model_id)
 
         # Set args
-        last, epoch, final_epoch, best_fitness, fi = (
-            args[0],
-            args[1],
-            args[2],
-            args[3],
-            args[4],
-        )
+        last, epoch, final_epoch, best_fitness, fi = args[:5]
+        is_best = best_fitness == fi
 
-        is_best = (best_fitness == fi).all()
-
-        thread = threading.Thread(
-            target=self._upload_model,
-            args=(epoch, is_best, last),
-            daemon=True,
-        ).start()
+        threading.Thread(target=self._upload_model, args=(epoch, is_best, last), daemon=True).start()
 
     def _upload_model(self, epoch, is_best, weights):
         api_url = HUB_API_ROOT + "model-checkpoint"
@@ -61,8 +50,7 @@ class HUBLogger:
             *args   last, best, plots, epoch
         """
         # Set args
-        last, best, plots, epoch, results = (args[0], args[1], args[2],
-                                             args[3], args[4])
+        last, best, plots, epoch, results = args[:5]
 
         # mAP0.5:0.95
         map_new = results[3]
